@@ -35,7 +35,7 @@
  * \date June 2008
  */
 
-//#define MANUAL_POLL
+// #define MANUAL_POLL
 
 #include "UdpDataProtocol.h"
 
@@ -49,7 +49,7 @@
 #include "JackTrip.h"
 #include "jacktrip_globals.h"
 #ifdef _WIN32
-//#include <winsock.h>
+// #include <winsock.h>
 #include <stdio.h>
 #include <winsock2.h>  //cc need SD_SEND
 #pragma comment(lib, "ws2_32.lib")
@@ -85,6 +85,11 @@ UdpDataProtocol::UdpDataProtocol(JackTrip* jacktrip, const runModeT runmode,
     , mBindPort(bind_port)
     , mPeerPort(peer_port)
     , mRunMode(runmode)
+#if defined(_WIN32)
+    , mSocket(INVALID_SOCKET)
+#else
+    , mSocket(-1)
+#endif
     , mAudioPacket(NULL)
     , mFullPacket(NULL)
     , mUdpRedundancyFactor(udp_redundancy_factor)
@@ -112,16 +117,36 @@ UdpDataProtocol::~UdpDataProtocol()
 {
     delete[] mAudioPacket;
     delete[] mFullPacket;
-    if (mRunMode == RECEIVER) {
-#ifdef _WIN32
-        closesocket(mSocket);
-#else
-        ::close(mSocket);
-#endif
-    }
+    closeSocket();
     wait();
 }
 
+//*******************************************************************************
+void UdpDataProtocol::stop()
+{
+    closeSocket();
+    DataProtocol::stop();
+}
+
+//*******************************************************************************
+void UdpDataProtocol::closeSocket()
+{
+    if (mRunMode != RECEIVER) {
+        return;
+    }
+#if defined(_WIN32)
+    if (mSocket != INVALID_SOCKET) {
+        closesocket(mSocket);
+        mSocket = INVALID_SOCKET;
+    }
+#else
+    if (mSocket != -1) {
+        ::close(mSocket);
+        mSocket = -1;
+    }
+#endif
+}
+
 //*******************************************************************************
 void UdpDataProtocol::setPeerAddress(const char* peerHostOrIP)
 {
@@ -372,7 +397,7 @@ functions. DWORD n_bytes; WSABUF buffer; int error; buffer.len = n; buffer.buf =
                            sizeof(mPeerAddr));
     }
     return n_bytes;
-    //#endif
+    // #endif
 }
 
 //*******************************************************************************
