@@ -241,7 +241,7 @@ void VirtualStudio::show()
             "Click \"OK\" to proceed to classic mode.\n\n"
             "Details: JackTrip failed to load the QML view. "
             "This is likely caused by missing QML plugins. "
-            "Please consult help.jacktrip.org for possible solutions.");
+            "Please consult support.jacktrip.com for possible solutions.");
         msgBox.setWindowTitle(QStringLiteral("JackTrip Is Missing QML Modules"));
         connect(&msgBox, &QMessageBox::finished, this, &VirtualStudio::toStandard,
                 Qt::QueuedConnection);
@@ -639,7 +639,6 @@ void VirtualStudio::joinStudio()
     // pop studioToJoin
     const QString targetId = m_studioToJoin;
     setStudioToJoin("");
-    emit studioToJoinChanged();
 
     // stop audio if already running (settings or setup windows)
     m_audioConfigPtr->stopAudio(true);
@@ -734,14 +733,14 @@ void VirtualStudio::logout()
     query.addQueryItem(QStringLiteral("client_id"), AUTH_CLIENT_ID);
     if (m_testMode) {
         query.addQueryItem(QStringLiteral("returnTo"),
-                           QStringLiteral("https://test.jacktrip.org/"));
+                           QStringLiteral("https://next-test.jacktrip.com/"));
     } else {
         query.addQueryItem(QStringLiteral("returnTo"),
-                           QStringLiteral("https://app.jacktrip.org/"));
+                           QStringLiteral("https://www.jacktrip.com/"));
     }
 
     logoutURL.setQuery(query);
-    launchBrowser(logoutURL);
+    QDesktopServices::openUrl(logoutURL);
 
     m_auth->logout();
 
@@ -831,7 +830,7 @@ void VirtualStudio::connectToStudio()
     m_studioSocketPtr->openSocket();
 
     // Check if we have an address for our server
-    if (m_currentStudio.status() != "Ready" && m_currentStudio.isAdmin() == true) {
+    if (m_currentStudio.status() != "Ready") {
         m_connectionState = QStringLiteral("Waiting...");
         emit connectionStateChanged();
     } else {
@@ -843,8 +842,20 @@ void VirtualStudio::connectToStudio()
 
 void VirtualStudio::completeConnection()
 {
+    // sanity check
     if (m_currentStudio.id() == ""
         || m_currentStudio.status() == QStringLiteral("Disabled")) {
+        processError("Studio session has ended");
+        return;
+    }
+
+    // these shouldn't happen
+    if (m_currentStudio.status() != "Ready") {
+        processError("Studio session is not ready");
+        return;
+    }
+    if (m_currentStudio.host().isEmpty()) {
+        processError("Studio host is unknown");
         return;
     }
 
@@ -884,27 +895,8 @@ void VirtualStudio::completeConnection()
         // increment buffer_strategy by 1 for array-index mapping
         int buffer_strategy = m_audioConfigPtr->getBufferStrategy() + 1;
         // adjust buffer_strategy for PLC "auto" mode menu item
-        if (buffer_strategy == 3) {
-            // run PLC without worker (4)
-            buffer_strategy = 4;
-            /*
-            // I don't believe this is still necessary,
-            // after splitting the input and output RtAudio streams
-            // See https://github.com/jacktrip/jacktrip/pull/1235
-            if (useRtAudio) {
-                // if same device for input and output,
-                // run PLC without worker (4)
-                if (input == output)
-                    buffer_strategy = 4;
-                // else run PLC with worker (3)
-                // to reduce crackles
-            } else {
-                // run PLC without worker (4)
-                buffer_strategy = 4;
-            }
-            */
-        } else if (buffer_strategy == 5) {
-            buffer_strategy = 3;  // run PLC with worker (3)
+        if (buffer_strategy == 4 || buffer_strategy == 5) {
+            buffer_strategy = 3;
         }
 
         // create a new JackTrip instance
@@ -984,102 +976,56 @@ void VirtualStudio::triggerReconnect(bool refresh)
 
 void VirtualStudio::disconnect()
 {
-    m_connectionState = QStringLiteral("Disconnecting...");
-    emit connectionStateChanged();
-    setConnectedErrorMsg("");
-
+    // stop jackrip if it's running
     if (m_jackTripRunning) {
         m_devicePtr->stopJackTrip(false);
         // persist any volume level or device changes
         m_audioConfigPtr->saveSettings();
-    } else {
-        // How did we get here? This shouldn't be possible, but include for safety.
-        if (m_isExiting) {
-            emit signalExit();
-        } else if (m_onConnectedScreen) {
-            emit disconnected();
-            m_onConnectedScreen = false;
-        }
-    }
-
-    // Restart our studio refresh timer.
-    if (!m_isExiting) {
-        m_refreshTimer.start();
     }
 
     m_connectionState = QStringLiteral("Disconnected");
     emit connectionStateChanged();
+    setConnectedErrorMsg("");
 
-    if (!m_currentStudio.id().isEmpty()) {
-        emit openFeedbackSurveyModal(m_currentStudio.id());
+    if (m_isExiting) {
+        emit signalExit();
+        return;
     }
 
-    // cleanup
-    m_currentStudio.setId("");
-    emit currentStudioChanged();
+    // if this occurs on the setup or settings screen (for example, due to an issue with
+    // devices) then don't emit disconnected, as that would move you back to the "Browse"
+    // screen
+    if (m_onConnectedScreen) {
+        m_onConnectedScreen = false;
+        emit disconnected();
+        // Refresh studios and restart timer
+        refreshStudios(0, true);
+        m_refreshTimer.start();
+    }
+
+    if (!m_jackTripRunning) {
+        return;
+    }
+    m_jackTripRunning = false;
 
     if (!m_studioSocketPtr.isNull()) {
         m_studioSocketPtr->closeSocket();
         m_studioSocketPtr->disconnect();
         m_studioSocketPtr.reset();
     }
-}
 
-void VirtualStudio::manageStudio(const QString& studioId, bool start)
-{
-    if (studioId.isEmpty()) {
-        processError("Manage requires a unique studio identifier");
-        return;
-    }
-    QUrl url;
-    if (!start) {
-        url = QUrl(
-            QStringLiteral("https://%1/studios/%2").arg(m_api->getApiHost(), studioId));
-    } else {
-        QString expiration =
-            QDateTime::currentDateTimeUtc().addSecs(60 * 30).toString(Qt::ISODate);
-        QJsonObject json      = {{QLatin1String("enabled"), true},
-                            {QLatin1String("expiresAt"), expiration}};
-        QJsonDocument request = QJsonDocument(json);
+    // reset network statistics
+    m_networkStats = QJsonObject();
 
-        QNetworkReply* reply = m_api->updateServer(studioId, request.toJson());
-        connect(reply, &QNetworkReply::finished, this, [&, reply]() {
-            if (reply->error() != QNetworkReply::NoError) {
-                m_connectionState      = QStringLiteral("Unable to Start Studio");
-                QJsonDocument errorDoc = QJsonDocument::fromJson(reply->readAll());
-                if (!errorDoc.isNull()) {
-                    QJsonObject errorObj = errorDoc.object();
-                    if (errorObj.contains("error")) {
-                        QString errorMessage = errorObj.value("error").toString();
-                        if (errorMessage.contains(
-                                "Only one studio may be running at a time")) {
-                            setConnectedErrorMsg("one-studio-limit-reached");
-                        }
-                    }
-                }
-                emit connectionStateChanged();
-            } else {
-                setConnectedErrorMsg("");
-                QByteArray response       = reply->readAll();
-                QJsonDocument serverState = QJsonDocument::fromJson(response);
-                if (serverState.object()[QStringLiteral("status")].toString()
-                    == QLatin1String("Starting")) {}
-            }
-            reply->deleteLater();
-        });
+    if (!m_currentStudio.id().isEmpty()) {
+        emit openFeedbackSurveyModal(m_currentStudio.id());
+        m_currentStudio.setId("");
+        emit currentStudioChanged();
     }
-    QDesktopServices::openUrl(url);
-}
 
-void VirtualStudio::launchVideo(const QString& studioId)
-{
-    if (studioId.isEmpty()) {
-        processError("Manage requires a unique studio identifier");
-        return;
-    }
-    QUrl url = QUrl(
-        QStringLiteral("https://%1/studios/%2/live").arg(m_api->getApiHost(), studioId));
-    QDesktopServices::openUrl(url);
+#ifdef __APPLE__
+    m_noNap.enableNap();
+#endif
 }
 
 void VirtualStudio::createStudio()
@@ -1267,33 +1213,6 @@ void VirtualStudio::connectionFinished()
 
     // use disconnect function to handle reset of all internal flags and timers
     disconnect();
-
-    // reset network statistics
-    m_networkStats = QJsonObject();
-
-    if (m_isExiting) {
-        emit signalExit();
-        return;
-    }
-
-    if (!m_jackTripRunning) {
-        return;
-    }
-
-    m_jackTripRunning = false;
-    m_connectionState = QStringLiteral("Disconnected");
-    emit connectionStateChanged();
-
-    // if this occurs on the setup or settings screen (for example, due to an issue with
-    // devices) then don't emit disconnected, as that would move you back to the "Browse"
-    // screen
-    if (m_onConnectedScreen) {
-        m_onConnectedScreen = false;
-        emit disconnected();
-    }
-#ifdef __APPLE__
-    m_noNap.enableNap();
-#endif
 }
 
 void VirtualStudio::processError(const QString& errorMessage)
@@ -1395,17 +1314,6 @@ void VirtualStudio::restartStudioSocket()
     }
 }
 
-void VirtualStudio::launchBrowser(const QUrl& url)
-{
-    std::cout << "Launching Browser" << std::endl;
-    bool success = QDesktopServices::openUrl(url);
-    if (success) {
-        std::cout << "Success" << std::endl;
-    } else {
-        std::cout << "Unable to open URL" << std::endl;
-    }
-}
-
 void VirtualStudio::updatedStats(const QJsonObject& stats)
 {
     QJsonObject newStats;
@@ -1527,6 +1435,8 @@ void VirtualStudio::getServerList(bool signalRefresh, int index)
                     serverInfo->setId(servers.at(i)[QStringLiteral("id")].toString());
                     serverInfo->setSessionId(
                         servers.at(i)[QStringLiteral("sessionId")].toString());
+                    serverInfo->setStreamId(
+                        servers.at(i)[QStringLiteral("streamId")].toString());
                     serverInfo->setInviteKey(
                         servers.at(i)[QStringLiteral("inviteKey")].toString());
                     serverInfo->setCloudId(
