@@ -57,7 +57,7 @@
 #include <QStandardPaths>
 #include <QTextStream>
 // TODO: Add support for QtWebView
-//#include <QtWebView>
+// #include <QtWebView>
 #include <QtWebEngineQuick/qtwebenginequickglobal.h>
 
 #include "JTApplication.h"
@@ -182,7 +182,7 @@ QCoreApplication* createApplication(int& argc, char* argv[])
 #if !defined(NO_VS) && QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         // Enables resource sharing between the OpenGL contexts
         QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
-        QCoreApplication::setAttribute(Qt::AA_UseDesktopOpenGL);
+        // QCoreApplication::setAttribute(Qt::AA_UseDesktopOpenGL);
         // QCoreApplication::setAttribute(Qt::AA_UseOpenGLES);
 
         // QQuickWindow::setGraphicsApi(QSGRendererInterface::Direct3D11);
@@ -216,6 +216,11 @@ void qtMessageHandler([[maybe_unused]] QtMsgType type,
 #endif  // NO_GUI
 }
 
+void outputError(const QString& msg)
+{
+    std::cerr << "Error: " << msg.toStdString() << std::endl;
+}
+
 #ifndef _WIN32
 static int setupUnixSignalHandler(void (*handler)(int))
 {
@@ -462,13 +467,16 @@ int main(int argc, char* argv[])
     } else {
 #endif  // NO_GUI
         // Otherwise use the non-GUI version, and parse our command line.
-#ifndef PSI
-        QLoggingCategory::setFilterRules(QStringLiteral("*.debug=true"));
-#endif
         try {
             Settings settings;
             settings.parseInput(argc, argv);
 
+#ifndef PSI
+            if (gVerboseFlag) {
+                QLoggingCategory::setFilterRules(QStringLiteral("*.debug=true"));
+            }
+#endif
+
             // Either start our hub server or our jacktrip process as appropriate.
             if (settings.isHubServer()) {
                 udpHub.reset(settings.getConfiguredHubServer());
@@ -478,6 +486,8 @@ int main(int argc, char* argv[])
                 QObject::connect(udpHub.data(), &UdpHubListener::signalStopped,
                                  app.data(), &QCoreApplication::quit,
                                  Qt::QueuedConnection);
+                QObject::connect(udpHub.data(), &UdpHubListener::signalError,
+                                 outputError);
                 QObject::connect(udpHub.data(), &UdpHubListener::signalError, app.data(),
                                  &QCoreApplication::quit, Qt::QueuedConnection);
 #ifndef _WIN32
@@ -495,6 +505,7 @@ int main(int argc, char* argv[])
                 QObject::connect(jackTrip.data(), &JackTrip::signalProcessesStopped,
                                  app.data(), &QCoreApplication::quit,
                                  Qt::QueuedConnection);
+                QObject::connect(jackTrip.data(), &JackTrip::signalError, outputError);
                 QObject::connect(jackTrip.data(), &JackTrip::signalError, app.data(),
                                  &QCoreApplication::quit, Qt::QueuedConnection);
 #ifndef _WIN32
